==> haskell-ordered-containers-0.2.4-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-Kfa4oDhdv4i5d1D5c8Fvse
key:                  ordered-containers-0.2.4-Kfa4oDhdv4i5d1D5c8Fvse
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  c6fa440384e29a589577afc59e85141d
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-Kfa4oDhdv4i5d1D5c8Fvse
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.7.0-bh6X3bZPF56LQTYQ27khw

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ordered-containers-0.2.4-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-5kPssUtGfbk3KH405kLpj1
key:                  ordered-containers-0.2.4-5kPssUtGfbk3KH405kLpj1
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  b6e28db8e178fead6a279d6001db5107
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-5kPssUtGfbk3KH405kLpj1
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.7.0-5RC0vb199EtDGUMphsJuko

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
